@@ -123,6 +123,7 @@ ExtFunc void plug_set_keyword(struct arglist*, const char *);
 
 ExtFunc void plug_set_id(struct arglist *, int);
 ExtFunc void plug_set_cve_id(struct arglist *, char *);
+ExtFunc void plug_set_bugtraq_id(struct arglist *, char *);
 ExtFunc void plug_set_see_also(struct arglist *, char *);
 
 #ifdef HAVE_SSL
@@ -149,6 +150,7 @@ ExtFunc unsigned int plug_get_host_open_port(struct arglist * desc);
 ExtFunc void plug_add_host(struct arglist *, struct arglist *);
 ExtFunc int plug_get_launch(struct arglist *);
 ExtFunc char* plug_get_cve_id(struct arglist*);
+ExtFunc char* plug_get_bugtraq_id(struct arglist*);
 ExtFunc void plug_require_key(struct arglist *, const char *);
 ExtFunc void plug_exclude_key(struct arglist *, const char *);
 ExtFunc void plug_require_port(struct arglist *, const char *);
@@ -187,6 +189,7 @@ ExtFunc char ** append_argv (char **argv, char *opt);
 ExtFunc void    destroy_argv (char **argv);
 ExtFunc void (*pty_logger(void(*)(const char *, ...)))(const char *, ...);
 
+ExtFunc FILE*	nessus_popen(const char*, const char**, pid_t*);
 
 /* 
  * Management of the portlists
@@ -291,15 +294,16 @@ ExtFunc int get_mac_addr(struct in_addr, char**);
  */
 /* Actions types of the plugins */
 #define ACT_LAST		ACT_DENIAL
-#define ACT_FIRST		ACT_SETTINGS
+#define ACT_FIRST		ACT_SCANNER
 
 #define ACT_DENIAL 		6
 #define ACT_DESTRUCTIVE_ATTACK 	5
 #define ACT_MIXED_ATTACK 	4
 #define ACT_ATTACK 		3
 #define ACT_GATHER_INFO 	2
-#define ACT_SCANNER 		1
-#define ACT_SETTINGS		0
+#define ACT_SETTINGS		1
+#define ACT_SCANNER 		0
+
 
 
 
@@ -369,8 +373,9 @@ ExtFunc int stream_set(int, fd_set*);
 ExtFunc int stream_isset(int, fd_set*);
 
 
-
-ExtFunc int wait_for_free_bpf(int);
-ExtFunc int release_bpf(int);
+ExtFunc int bpf_server();
+ExtFunc int bpf_open_live(char*, char*);
+ExtFunc u_char* bpf_next(int, struct pcap_pkthdr *);
+ExtFunc void bpf_close(int);
 
 #endif
