@@ -18,6 +18,6 @@
 
 #define NL_MAJOR 1
 #define NL_MINOR 2
-#define NL_REV   5
-#define NL_DATE  "Oct 16, 2002"
-#define VERSION  "1.2.5"
+#define NL_REV   7
+#define NL_DATE  "Jun 30, 2003"
+#define VERSION  "1.2.7"
